<?php
namespace Teknisa\FIS\Controllers;

use Teknisa\FIS\Services\Ger58000ApuracaoIRPJCSLLService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Request\DataSet as RequestDataSet;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;


class Ger58000ApuracaoIRPJCSLLController extends \Teknisa\FIS\Controllers\TeknisaCrud{

  protected $dataSourceName;
  protected $parameterBag;
  protected $crudService;
  protected $service;

  public function __construct($crudService, ParameterBag $parameterBag, Ger58000ApuracaoIRPJCSLLService $service) {
    $this->service = $service;
    parent::__construct($crudService, $parameterBag);
  }

  public function findParamImposto(DTO\Request\Filter $request, DTO\Response $response) {
    $this->dataSourceName = 'paramimposto_aliq';
    parent::find($request, $response);
  }

  public function saveParamImposto(DTO\Request\Row $request, DTO\Response $response) {
    $this->dataSourceName = 'paramimposto_aliq';

    try {
      $vrlimadicirpj = $request->getRow()['VRLIMADICIRPJ'];
      $vrpercadicir = $request->getRow()['VRPERCADICIR'];
      $vraliqir = $request->getRow()['VRALIQIR'];
      $vraliqcsll = $request->getRow()['VRALIQCSLL'];
      $rowAux = array($vrlimadicirpj, $vrpercadicir, $vraliqir, $vraliqcsll);
      
      $row = $this->service->validateParamImposto($rowAux);
      $result = $this->service->checkParamImposto();
  
  
      if (empty($result)) {
        $row['NRSEQPARAMIMPOSTO'] = $this->service->generateNrSeq('PARAMIMPOSTO');
        $row['__is_new'] = true;
      } else {
        $row['NRSEQPARAMIMPOSTO'] = $result[0]['NRSEQPARAMIMPOSTO'];
        $row['__is_new'] = false;
      }
      
       $params = array(
         "VRLIMADICIRPJ" => $row[0],
         "VRPERCADICIR" =>$row[1],
         "VRALIQIR" => $row[2],
         "VRALIQCSLL" => $row[3],
         "NRSEQPARAMIMPOSTO" =>$row['NRSEQPARAMIMPOSTO']
         );
      
      $this->service->insertParamImposto($params);
    } catch (\Exception $e) {
      $response->setError(new Error($e->getMessage(), $e->getCode()));
    }

  }



  public function findAliqIRPJCSLL(DTO\Request\Filter $request, DTO\Response $response) {
    $this->dataSourceName = 'aliqirpjcsll_apuirpj';

    parent::find($request, $response);

  }

  public function saveAliqIRPJCSLL(DTO\Request\DataSet $request, DTO\Response $response) {
    $this->dataSourceName = 'aliqirpjcsll_apuirpj';
    $row = $request->getDataSet()->getRows()[0];

    try {

      $this->service->validateAliqIRPJCSLL($row);

      if ($row['__is_new']) {
        $row['NRSEQALIQIRPJ'] = $this->service->generateNrSeq('ALIQIRPJ');
        $newDataSet = new DataSet($this->dataSourceName, array($row));
        $newRequest = new RequestDataSet($newDataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
        $response->addDataSet(new DataSet($this->dataSourceName, array('NRSEQ' => $row['NRSEQALIQIRPJ'])));
        parent::save($newRequest, $response);
      }
      else {
        parent::save($request, $response);
      }

    } catch (\Exception $e) {
      $response->setError(new Error($e->getMessage(), $e->getCode()));
    }

  }

  /* Método para salvar apenas as alíquotas padrão (enviadas pelo dataset da request)
  que não estão presentes no banco de dados*/
  public function saveDefaultAliqIRPJCSLL(DTO\Request\DataSet $request, DTO\Response $response) {
    $this->dataSourceName = 'aliqirpjcsll_apuirpj';

    $rows = $request->getDataSet()->getRows();

    $result = $this->service->checkDefaultAliqIRPJCSLL($rows);

    foreach($result as $row) {
      $row['NRSEQALIQIRPJ'] = $this->service->generateNrSeq('ALIQIRPJ');
      $newDataSet = new DataSet($this->dataSourceName, array($row));
      $newRequest = new RequestDataSet($newDataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
      parent::save($newRequest, $response);
    }

  }

  public function deleteAliqIRPJCSLL(DTO\Request\Row $request, DTO\Response $response) {
    $this->dataSourceName = 'aliqirpjcsll_apuirpj';
    $row = $request->getRow();

    try {
      $this->service->validateDeleteAliqIRPJCSLL($row);
      parent::delete($request, $response);
    } catch (\Exception $e) {
      $response->setError(new Error($e->getMessage(), $e->getCode()));
    }

  }

  public function findParamapu(DTO\Request\Filter $request, DTO\Response $response) {
    $this->dataSourceName = 'paramapuirpj';

    parent::find($request, $response);

  }

  public function saveParamapu(DTO\Request\DataSet $request, DTO\Response $response) {
    $this->dataSourceName = 'paramapuirpj';
    $row = $request->getDataSet()->getRows()[0];


    try {
      $this->service->validateParamapu($row);

      if ($row['__is_new']) {
        $row['NRSEQPARAMAPU'] = $this->service->generateNrSeq('PARAMAPUIRPJ');
        $newDataSet = new DataSet($this->dataSourceName, array($row));
        $newRequest = new RequestDataSet($newDataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
        $response->addDataSet(new DataSet($this->dataSourceName, array('NRSEQ' => $row['NRSEQPARAMAPU'])));
        parent::save($newRequest, $response);

      }
      else {
        parent::save($request, $response);
      }

    } catch (\Exception $e) {
      $response->setError(new Error($e->getMessage(), $e->getCode()));
    }

  }

  public function deleteParamapu(DTO\Request\Row $request, DTO\Response $response) {
    $this->dataSourceName = 'paramapuirpj';

    parent::delete($request, $response);
  }

  public function findRecDespIRPJ(DTO\Request\Filter $request, DTO\Response $response) {
    $this->dataSourceName = 'recdespirpj_apuirpj';

    parent::find($request, $response);

  }

  public function saveRecDespIRPJ(DTO\Request\DataSet $request, DTO\Response $response) {
    $this->dataSourceName = 'recdespirpj_apuirpj';
    $row = $request->getDataSet()->getRows()[0];


    try {
      $this->service->validateRecDespIRPJ($row);

      if ($row['__is_new']) {
        $row['NRSEQRECDESPIRPJ'] = $this->service->generateNrSeq('RECDESPIRPJ');
        $newDataSet = new DataSet($this->dataSourceName, array($row));
        $newRequest = new RequestDataSet($newDataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
        $response->addDataSet(new DataSet($this->dataSourceName, array('NRSEQ' => $row['NRSEQRECDESPIRPJ'])));
        parent::save($newRequest, $response);

      }
      else {
        parent::save($request, $response);
      }

    } catch (\Exception $e) {
      $response->setError(new Error($e->getMessage(), $e->getCode()));
    }

  }

  public function deleteRecDespIRPJ(DTO\Request\Row $request, DTO\Response $response) {
    $this->dataSourceName = 'recdespirpj_apuirpj';

    parent::delete($request, $response);
  }

  public function findInfCtbIRPJ(DTO\Request\Filter $request, DTO\Response $response) {
    $this->dataSourceName = 'infctbirpj_apuirpj';

    parent::find($request, $response);
  }

  public function saveInfCtbIRPJ(DTO\Request\DataSet $request, DTO\Response $response) {
    $this->dataSourceName = 'infctbirpj_apuirpj';

    $row = $request->getDataSet()->getRows()[0];

    try {
      $this->service->validateInfCtbIRPJ($row);

      if ($row['__is_new']) {
        $row['NRSEQINFCTBIRPJ'] = $this->service->generateNrSeq('INFCTBIRPJ');
        $newDataSet = new DataSet($this->dataSourceName, array($row));
        $newRequest = new RequestDataSet($newDataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
        $response->addDataSet(new DataSet($this->dataSourceName, array('NRSEQ' => $row['NRSEQINFCTBIRPJ'])));
        parent::save($newRequest, $response);

      }
      else {
        parent::save($request, $response);
      }

    } catch (\Exception $e) {
      $response->setError(new Error($e->getMessage(), $e->getCode()));
    }

  }

  public function deleteInfCtbIRPJ(DTO\Request\Row $request, DTO\Response $response) {
    $this->dataSourceName = 'infctbirpj_apuirpj';

    parent::delete($request, $response);
  }

}
