<?php
namespace Teknisa\FIS\Modules\Acessorias\Controllers;

use Doctrine\ORM\EntityManager;
use Teknisa\FIS\Modules\Acessorias\Services\Fis03000DapiMgService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;

class Fis03000DapiMgController 
{
    protected $dapiMgService;
    
    public function __construct(EntityManager $entityManager, Fis03000DapiMgService $dapiMgService){
        $this->entityManager    = $entityManager;
        $this->dapiMgService    = $dapiMgService;
        set_time_limit(0);
    }
     
    /**
     * Função para realizar a exportação DAPI-MG
     */
    public function exportarDapiMg(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            $row["NMARQUIVO"] = str_replace(' ', '', $row["NMARQUIVO"]);
            
            // Chama a função de validação
            $fileName = $this->dapiMgService->exportarDapiMg($row);
            
            // Retorna o nome do arquivo
            $response->addDataset(new DataSet('columnsToReturn', ["fileName" => $fileName]));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    } 
    
    public function findAgendamento(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            
            $rows = $this->dapiMgService->findAgendamento();
            
            $dataSet = new DataSet('agendobrigacess_fis03000', $rows);
            $response->setDataSets(array($dataSet));
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    } 
    
    public function saveAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $fileName = $this->dapiMgService->saveAgendamento($row);
            
            $this->entityManager->commit();

            // Retorna o nome do arquivo exportado.
            $response->addDataset(new DataSet('columnsToReturn', array("fileName" => $fileName)));
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $this->dapiMgService->deleteAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function execAgendamentoDapiMg(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getParameters();
            
            $this->dapiMgService->execAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}