<?php
namespace Teknisa\FIS\Modules\Acessorias\Controllers;

use Doctrine\ORM\EntityManager;
use Teknisa\FIS\Modules\Acessorias\Services\Fis05500DotGiIcmsService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;

class Fis05500DotGiIcmsController 
{
    protected $dotGiIcmsService;
    
    public function __construct(EntityManager $entityManager, Fis05500DotGiIcmsService $dotGiIcmsService){
        $this->entityManager    = $entityManager;
        $this->dotGiIcmsService = $dotGiIcmsService;
        set_time_limit(0);
    }
     
    /**
     * Função para realizar a exportação DOT/GI-ICMS (Espírito Santo)
     */
    public function exportarDotGiIcms(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            $row["NMARQUIVO"] = str_replace(' ', '', $row["NMARQUIVO"]);
            
            // Chama a função de validação
            $fileName = $this->dotGiIcmsService->exportarDotGiIcms($row);
            
            // Retorna o nome do arquivo
            $response->addDataset(new DataSet('columnsToReturn', ["fileName" => $fileName]));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    } 
    
    public function findAgendamento(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            
            $rows = $this->dotGiIcmsService->findAgendamento();
            
            $dataSet = new DataSet('agendobrigacess_fis05500', $rows);
            $response->setDataSets(array($dataSet));
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    } 
    
    public function saveAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $fileName = $this->dotGiIcmsService->saveAgendamento($row);
            
            $this->entityManager->commit();

            // Retorna o nome do arquivo exportado.
            $response->addDataset(new DataSet('columnsToReturn', array("fileName" => $fileName)));
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $this->dotGiIcmsService->deleteAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function execAgendamentoDotGiIcms(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getParameters();
            
            $this->dotGiIcmsService->execAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}