<?php
namespace Teknisa\FIS\Modules\Acessorias\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Fis83000DiefPAFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }

    /*
     * Executa procedure para exportação do DIEF-PA [ARQUIVO_DIEF_PA].
     */
    public function callExportacaoProcedure($params) {
        $procedure = new StoredProcedure($this->connection, 'ARQUIVO_DIEF_PA');
        
        $procedure->addParam(new Param('P_CDIMPOSTO', Param::PARAM_INPUT, $params["CDIMPOSTO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));    
        $procedure->addParam(new Param('P_CDINSCESTA', Param::PARAM_INPUT   , $params["CDINSCESTA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $params["DTINICIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $params["DTFINAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_STPERIODO', Param::PARAM_INPUT, $params["STPERIODO"], Param::PARAM_TYPE_STR));    
        $procedure->addParam(new Param('P_STDECLARACAO', Param::PARAM_INPUT, $params["STDECLARACAO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_STDECLARESMOV', Param::PARAM_INPUT   , $params["STDECLARESMOV"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDTPTRIBUTACAO', Param::PARAM_INPUT, $params["IDTPTRIBUTACAO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDTPESCRITURACAO', Param::PARAM_INPUT, $params["IDTPESCRITURACAO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDTPCONTRIB', Param::PARAM_INPUT, $params["IDTPCONTRIB"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDSEMRECEITA', Param::PARAM_INPUT, $params["IDSEMRECEITA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDSEMSERVICOA', Param::PARAM_INPUT, $params["IDSEMSERVICOA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDTROCMUNICIP', Param::PARAM_INPUT, $params["IDTROCMUNICIP"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDSEMOPCARTAO', Param::PARAM_INPUT, $params["IDSEMOPCARTAO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDSEMSERVICOM', Param::PARAM_INPUT, $params["IDSEMSERVICOM"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQARQMAG', Param::PARAM_INPUT, $params["NRSEQARQMAG"], Param::PARAM_TYPE_STR));
    
        $procedure->execute();
    }
        /*
     * Função para excluir os dados gerados na procedure do DIEF-ES.
     */
    public function deleteDiefPAData($params) {
        // Query a ser executada.
        $sql = "DELETE FROM ARQMAGNETICO WHERE NRSEQARQMAG = :NRSEQARQMAG AND NRORG = :NRORG";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);
    }

    /*
     * Função para retornar os dados gerados na procedure do DIEF-ES.
     */
    public function getDiefPAData($params) {
        // Query a ser executada.
        //$sql = "SELECT T.NRSEQARQMAG, T.NRORDREGARQ, T.DSREGARQMAG , T.SQUENCIAL FROM( SELECT NRSEQARQMAG, NRORDREGARQ, DSREGARQMAG as DSREGARQMAG , ROWNUM as SQUENCIAL FROM ( SELECT NRSEQARQMAG, NRORDREGARQ, DSREGARQMAG as DSREGARQMAG FROM ARQMAGNETICO WHERE NRSEQARQMAG = :NRSEQARQMAG AND NRORG = :NRORG ORDER BY NRORDREGARQ, SUBSTR(DSREGARQMAG,1,17)))T";
        $sql = "SELECT T.NRSEQARQMAG, T.NRORDREGARQ, T.DSREGARQMAG, T.SQUENCIAL
                FROM
                (
                    SELECT NRSEQARQMAG, NRORDREGARQ, DSREGARQMAG as DSREGARQMAG, ROWNUM as SQUENCIAL
                    FROM
                    (
                        SELECT NRSEQARQMAG, NRORDREGARQ, DSREGARQMAG as DSREGARQMAG
                        FROM ARQMAGNETICO
                        WHERE NRSEQARQMAG = :NRSEQARQMAG
                        AND   NRORG = :NRORG
                        ORDER BY NRORDREGARQ, SUBSTR(DSREGARQMAG,1,17)
                    )
                )T";
    
        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);

        // Executa um fetch no primeiro dado, retornando-o.
        return $statement->fetchAll();
    }

}